"""
Agent Parameters relevant to retriever settings.
"""

"""
The filter to be applied when retrieving documents from the index.
"""
FILTERS = "index_filter_expression"

"""
The number of documents to retrieve from the index.
"""
TOP_N = "index_top_n"
